obelisk.asynchronous.consumer
=============================

.. automodule:: obelisk.asynchronous.consumer

   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: custom-class-template.rst
   
      Consumer
   